global cluster

/************************************/
/* PANEL W/TIME TRENDS, ALL COLUMNS */
/************************************/
use $tmp/dise_table_data, clear
eststo clear
global cluster cluster(vgroup)

/* Column : Post-2005 balanced */
eststo: reghdfe ln_enr_up i.dsgroup treatment_comp if all10_comp == 1 & dise_year >= 2005, absorb(vgroup##c.dise_year) $cluster

/* Column : unbalanced, road at some point */
eststo: reghdfe ln_enr_up i.dsgroup treatment_comp if unbal == 1, absorb(vgroup##c.dise_year) $cluster

/* Column : Super-balanced */
eststo: reghdfe ln_enr_up i.dsgroup treatment_comp if bal33_comp == 1, absorb(vgroup##c.dise_year) $cluster

label var treatment_comp "New Road"

global prefoot "\hline State-Year F.E.              & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E.        & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village Time Trends  & Yes  & Yes & Yes \\ " 
global prefoot $prefoot "       Panel Sample & Balanced Post-2004 & Unbalanced & 3 Years Pre/Post  \\ " "\hline "
estout_default using $out/app_table_v_time_trends, keep(treatment_comp) prefoot($prefoot)

/************************************/
/* RD EFFECTS ON OTHER PUBLIC GOODS */
/************************************/
/* prepare 2011 village  directory for merge with RD */
use $keys/pc11_village_key.dta, clear
ddrop pc01_state_id pc01_village_id
ddrop pc11_state_id pc11_village_id
save $tmp/foo, replace

use ~/iec1/pc11/pc11_vd_clean, clear
merge 1:1 pc11_state_id pc11_village_id using $tmp/foo, keepusing(pc01_state_id pc01_village_id) keep(matched) nogen
ddrop pc01_state_id pc01_village_id
save $tmp/pc11_vd, replace

/* open final RD dataset */
use $tmp/dise_rd_table_data, clear
keep if state_sample

/* get additional public goods from 2011 village directory */
global pc11_vars  pc11_vd_p_sch_gov_status pc11_vd_m_sch_gov_status pc11_vd_s_sch_gov_status pc11_vd_p_sch_priv_status pc11_vd_m_sch_priv_status pc11_vd_s_sch_priv_status pc11_vd_p_sch_gov pc11_vd_m_sch_gov pc11_vd_s_sch_gov pc11_vd_p_sch_priv pc11_vd_m_sch_priv pc11_vd_s_sch_priv pc11_vd_power_all pc11_vd_ph_cntr pc11_vd_mcw_cntr pc11_vd_comm_bank pc11_vd_power_dom 
merge 1:1 pc01_state_id pc01_village_id using $tmp/pc11_vd, keepusing($pc11_vars) keep(match) nogen

/* join public and private school vars */
foreach v in p m s {
  egen `v'_status = rowmax(pc11_vd_`v'_sch_gov_status  pc11_vd_`v'_sch_priv_status)
  egen `v'_count = rowmax(pc11_vd_`v'_sch_gov  pc11_vd_`v'_sch_priv)
}

winsorize pc11_vd_ph_cntr 0 1, replace

global rd_varlist p_status m_status s_status pc11_vd_power_all pc11_vd_ph_cntr pc11_vd_comm_bank

eststo clear
foreach v of varlist $rd_varlist {
  eststo: reghdfe `v' t left right ln_pop01 if band, absorb(subd_high_fe) 
}  

/* label variables */
label var t "Above Population Threshold"

estout_default using $out/app_table_rd_pgs, order(t) keep(t) prefoot("\hline")
estmod_header using $out/app_table_rd_pgs.tex, cstring(" Dep. Var. & Prim. School & Mid. School & Sec. School & Electricity & Health Center & Bank ")

/***************************************************/
/* summary stats on urban/rural wage / return gaps */
/***************************************************/
use ~/iec1/frozen_data/dise-replication/nss_round_55_individual, clear

gen unskilled_wage = wage if ed <= 5
gen   skilled_wage = wage if ed > 5 & !mi(ed)
gen     return_to_ed = ret_urban if sector == 2
replace return_to_ed = ret_rural if sector == 1

ren unskilled_wage wage_u
ren skilled_wage wage_s

gen     sector_string = "urban" if sector == 2
replace sector_string = "rural" if sector == 1

global f $tmp/nss_ests.csv
cap erase $f

foreach sector in urban rural {
  foreach v in wage_u wage_s {
    semean `v' if sector_string == "`sector'"

    local format %3.1f

    local mean: di `format' `r(mean)'
    local semean: di `format' `r(semean)'

    append_to_file using $f, s(`v'_`sector', `mean')
    append_to_file using $f, s(se_`v'_`sector', (`semean'))
  }
  count if sector_string == "`sector'"
  append_to_file using $f, s(n_`sector', `r(N)')
}

/* store mincerian returns */
/* mincerian return regression */
foreach sector in rural urban {
  areg ln_wage ed age age2 [pw=weight] if sector_string == "`sector'", absorb(sdgroup)
  local b: di %5.3f  _b["ed"]
  local se: di %5.3f _se["ed"]
  append_to_file using $f, s(ret_`sector', `b')
  append_to_file using $f, s(se_ret_`sector', (`se'))
}

/* create estimates file */
table_from_tpl, o($out/wage_ret_stats.tex) t(~/code/dise/tpl/wage_ret_stats.tpl) r($f)

