global dise2016 ~/iec2/dise/dise-2016
qui do ~/iecmerge/paul/dise/dise_progs

/*****************************/
/* prepare facility datasets */
/*****************************/
use $tmp/dise-new-Facility, clear

/* drop some variables we don't care about */
drop Classrooms_in_Good_Condition CLGOOD
drop Classrooms_require_major_repair CLMAJOR
drop Classrooms_require_minor_repair CLMINOR
drop Other_rooms_in_Good_Cond
drop Other_rooms_need_major_rep
drop Other_rooms_need_minor_rep
drop HMROOM_YN
drop Kitchen_Devices_Grant
drop Status_of_MDM
drop Computer_Aided_Learnin_Lab
drop Separate_Room_for_HeadMaster
drop Books_in_library BOOKINLIB
drop Medical_Checkup MEDCHK_YN
drop Ramps RAMPS_YN
drop No_of_Computers COMPUTER
drop Male_Tch
drop Female_Tch
drop NoResp_Tch
drop Head_Teacher
drop Graduate_Teachers
drop Tch_with_professional_Qualificat
drop Days_involved_in_non_tch_assgn
drop Teachers_involved_in_non_tch_ass
drop Column1
drop Clrooms
drop Clgood
drop Clmajor
drop ClMinor
drop OthGood
drop OthMajor
drop OthMinor
drop KITDEVGRANT_YN
drop MEALSINSCH
drop CAL_YN
drop HMRoom_YN
drop BookinLib 
drop MedChk_YN
drop Ramps_YN
drop Computer
drop Tch_Male
drop Tch_Female
drop Tch_NR
drop HeadTch
drop GradAbove
drop TchWithProf
drop DaysInvld
drop TchInvld
drop Book_Bank

/* combine some variables */
combine_vars Building_Status BLDSTATUS, gen(building_status)
combine_vars Tot_Clrooms CLROOMS, gen(num_classrooms)
combine_vars Toilet_Common Toilet_Common_YN Toilet_C, gen(toilet_common)
combine_vars Toilet_Boys TOILETB Toilet_Boys_YN Toiletb, gen(toilet_boys)
combine_vars Toilet_Girls TOILET_G Toilet_Girls_YN Toilet_g, gen(toilet_girls)
combine_vars Electricity Electric_YN ELECTRIC_YN, gen(elec)
combine_vars Boundary_Wall Bndrywall BNDRYWALL, gen(wall)
combine_vars Library_YN library_YN LIBRARY_YN, gen(library)
combine_vars PGround_YN PlayGround PGROUND_YN, gen(playground)
combine_vars Drinking_Water Water WATER, gen(water)

/* MP 2009-10 is a copy of AP 2014-15 -- drop it until further notice */
assert !mi(dise_state)
drop if dise_state == "Madhya-Pradesh" & year == "2009-2010"

/* run common cleaning steps */
dise_clean_common

/* rename some variables */
ren Blackboard blackboard

/* Recode some variables */

/* Define non-functional electricity as no electricity */
destring elec, replace
replace elec = . if inlist(elec, 0, 5, 9)
gen electricity_broken = elec == 3 if !mi(elec)
recode elec 2 = 0
recode elec 3 = 0

/* compress, order and save */
compress
order dise_state year vilcd schcd 
save $dise2016/dise-new-facility-clean, replace

/***********************************/
/* prepare main enrollment dataset */
/***********************************/
use $tmp/dise-new-TotalEnrolment, clear


/* run common cleaning steps */
dise_clean_common

/* combine variables */
forval i = 1/12 {
  combine_vars Class`i'_Total_Enr_Boys  C`i'_TOTB , gen(enr_all_b`i')
  combine_vars Class`i'_Total_Enr_Girls C`i'_TOTG , gen(enr_all_g`i')
}

/* combine exam scores */
foreach group in Boys Girl {
  local g = lower(substr("`group'", 1, 1))
  
  /* class 5 numbers */
  combine_vars C5_Appeared_`group' APPR`g'5, gen(appear_5`g')
  combine_vars C5_Passed_`group' PASS`g'5, gen(pass_5`g')
  combine_vars C5_Passed_with_more_than_60_`group' P60`g'5, gen(m60_5`g')

  /* class 7 or 8 numbers */
  combine_vars C7_Appeared_`group' APPR`g'8, gen(appear_7`g')
  combine_vars C7_Passed_`group' PASS`g'8, gen(pass_7`g')
  combine_vars C7_Passed_with_more_than_60_`group' P60`g'8, gen(m60_7`g')
}

/* destring exam scores */
cap destring appear* pass* m60*, replace

/* run generic cleaning function */
dise_clean_enr, caste(all) 

/* combine boys and girls exam scores in new data */
egen appear7 = rowtotal(appear_7b appear_7g)
egen pass7 = rowtotal(pass_7b pass_7g)
egen m607 = rowtotal(m60_7g m60_7b)

/* compress, order and save */
compress
order dise_state year vilcd schcd 
save $dise2016/dise-new-enr-clean, replace

/****************************/
/* prepare general datasets */
/****************************/
use $tmp/dise-new-General, clear


/* run common cleaning steps */
dise_clean_common

/* drop vars we don't care about */
drop Medium1 MEDINSTR1
drop Medium2 MEDINSTR2
drop Medium3 MEDINSTR3
drop Medium4 MEDINSTR4
drop Distance_BRC 
drop Distance_CRC
drop Pre_Pry_Students  PPSEC_YN PPSTUDENT
drop Shift_School_YN
drop No_of_Working_Days WORKDAYS_PR  WORKDAYS_UPR  WORKDAYS_SEC  WORKDAYS_HSEC
drop No_of_Acad_Inspection NOINSPECT
drop Residential_Sch_Type SCHRES_YN RESITYPE
drop Pre_Pry_Teachers PPTEACHER
drop Visits_by_BRC  VISITSBRC
drop Visits_by_CRC VISITSCRC
drop School_Dev_Grant_Recd SCHMNTCGRANT_R 
drop School_Dev_Grant_Expnd SCHMNTCGRANT_E
drop TLM_Grant_Recd
drop TLM_Grant_Expnd
drop Funds_from_students_Recd FUNDS_R
drop Funds_from_students_Expnd FUNDS_E
drop BOARDSEC BOARDHSEC

/* review these ones -- not sure what they mean */
drop SCHMGTS SCHMGTHS SCHSHI_YN CONTI_R  CONTI_E 

/* rename some vars */
rename Pre_Pry_YN         preprimary

/* combine some vars */
combine_vars RURURB Rural_Urban           , gen(rururb)
combine_vars Yeur_Estd ESTDYEAR           , gen(year_established)
combine_vars Residential_Sch_YN SCHRES_YN , gen(residential)
combine_vars SCHMGT Sch_Management        , gen(schmgt)
combine_vars LOWCLASS  Lowest_Class       , gen(lowest_class)
combine_vars HIGHCLASS Highest_Class      , gen(highest_class)
combine_vars SCHCAT Sch_Category          , gen(schcat)
combine_vars SCHTYPE School_Type          , gen(schtype)

/* compress, order and save */
compress
order dise_state year vilcd schcd 
save $dise2016/dise-new-general-clean, replace

/**********************/
/* SC Enrollment data */
/**********************/
use $tmp/dise-new-SCEnrolment.dta, clear


/* run common cleaning steps */
dise_clean_common

/* combine variables */
forval i = 1/12 {
  combine_vars Class`i'_SC_Enr_Boys  C`i'_CB , gen(enr_sc_b`i')
  combine_vars Class`i'_SC_Enr_Girls C`i'_CG , gen(enr_sc_g`i')
}

/* run generic enrollment cleaning function */
dise_clean_enr, caste(sc)

/* compress, order and save */
compress
order dise_state year vilcd schcd 
save $dise2016/dise-new-enr-sc, replace

/**************************/
/* prepare basic datasets */
/**************************/
use $tmp/dise-new-Basic, clear


/* run common cleaning steps */
dise_clean_common

/* clean variable names */
combine_vars District_Name DISTNAME      , gen(district)
combine_vars School_Name   SCHOOL_NAME   , gen(school_name)
combine_vars Block_Name    BLOCK_NAME    , gen(dise_block_name)
combine_vars Cluster_Name  CLUSTER_NAME  , gen(dise_cluster_name)
combine_vars Village_Name  VILLAGE_NAME  , gen(dise_village_name )
combine_vars Pincode       PINCODE       , gen(pincode)

/* compress, order and save */
compress
order dise_state year vilcd schcd 
save $dise2016/dise-new-basic-clean, replace

