/***************************************************/
/* PREPARE ELECTRICITY-RELEVANT VARS FROM OLD DISE */
/***************************************************/
global dise_inf_vars toilet_any elec med board lib play ramp computer water_tap water_taporpump bndrywall_pucca bndrywall_none water_any
global dise_enr_vars enr_total enr_up enr_b enr_g enr_p enr_up_b enr_up_g enr_p_b enr_p_g
global dise_exam_vars appear5 pass5 m605 appear7 pass7 m607 enr5 enr7 enr_cl4 enr_cl5 enr_cl7 enr_cl8 appear5 pass5 m605

/***************************************/
/* create unique pc01-pc11 village key */
/***************************************/
use $keys/pc11_village_key, clear
ddrop pc11_state_id pc11_village_id pc01_state_id pc01_village_id
ddrop pc11_state_id pc11_village_id
ddrop pc01_state_id pc01_village_id 
save $tmp/pc11_village_key_unique, replace

/***********************************************************/
/* get the parts we need from education.dta                */
/***********************************************************/

cap confirm filename $tmp/education.dta
if _rc {
  cd $tmp
  shell unzip $dise/ed.zip
}
use $tmp/education.dta, clear

rename vilid vilcd

drop enr_ci*

/* create boys / girls primary/upper primary cuts */
foreach v in b g {
  egen enr_up_`v' = rowtotal(enr_sc`v'6 enr_sc`v'7 enr_sc`v'8)
  replace enr_up_`v' = . if mi(enr_sc`v'6) & mi(enr_sc`v'7) & mi(enr_sc`v'8)

  egen enr_p_`v' = rowtotal(enr_sc`v'1 enr_sc`v'2 enr_sc`v'3 enr_sc`v'4 enr_sc`v'5)
  replace enr_p_`v' = . if mi(enr_sc`v'1) & mi(enr_sc`v'2) & mi(enr_sc`v'3) & mi(enr_sc`v'4) & mi(enr_sc`v'5)
}
  
  
/* cut to data that will be used */
keep schcd state year vilcd schcat school $dise_enr_vars $dise_exam_vars $dise_inf_vars schmgt rural
  
/* merge to pc01 village key */
merge m:1 vilcd using $dise/dise_village_key, keepusing(pc01_state_id pc01_village_id dise_match_source) nogen keep(master match)

/* clean year variable */
replace year = year + 2000
compress
save $tmp/dise-old-short, replace

/**********************************************/
/* match new dise at school level to old dise */
/**********************************************/
use $tmp/dise-new-short, clear

/* transform year variable to correspond to old dise */
ren year year_new
gen year = real(substr(year_new, 1, 4))

/* prefix all dise vars so no overwriting takes place */
rename * new_*
ren new_vilcd vilcd
ren new_schcd schcd
ren new_year year

/* merge at school level to old DISE */
merge 1:1 vilcd schcd year using $tmp/dise-old-short, gen(_merge_old_new) update

tag vilcd

/* drop villages that are only in the old dataset --- these have no recent data */
bys vilcd: egen any_non_two = max(_merge_old_new != 2)
count if vtag
count if any_non_two == 0 & vtag
drop if any_non_two == 0
drop any_non_two
/* remaining villages have at least a 1 (new data only) or a match */

tag vilcd year

/* consolidate variables of interest, and overwrite old with new */
replace elec = new_elec if !mi(new_elec)
replace enr_p = new_enr_all_p if !mi(new_enr_all_p)
replace enr_up = new_enr_all_up if !mi(new_enr_all_up)
replace enr_total = new_enr_all if !mi(new_enr_all)
replace enr_p = new_enr_all_p if !mi(new_enr_all_p)
replace enr_up = new_enr_all_up if !mi(new_enr_all_up)
replace enr_b = new_enr_all_b if !mi(new_enr_all_b)
replace enr_g = new_enr_all_g if !mi(new_enr_all_g)
replace enr_up_b = new_enr_all_up_b if !mi(new_enr_all_up_b)
replace enr_up_g = new_enr_all_up_g if !mi(new_enr_all_up_g)
replace enr_p_b = new_enr_all_p_b if !mi(new_enr_all_p_b)
replace enr_p_g = new_enr_all_p_g if !mi(new_enr_all_p_g)
replace appear7 = new_appear7 if !mi(new_appear7)
replace pass7   = new_pass7 if !mi(new_pass7)
replace m607    = new_m607 if !mi(new_m607)

replace rural = 1 if new_rururb == "1" & !mi(new_rururb)
replace rural = 0 if new_rururb == "2" & !mi(new_rururb)
drop new_rururb

replace schcat = 1 if inlist(new_schcat, "1", "10", "11", "12", "13", "14", "17", "19") & mi(schcat)
replace schcat = 2 if inlist(new_schcat, "2") & mi(schcat)
replace schcat = 3 if inlist(new_schcat, "3") & mi(schcat)
replace schcat = 4 if inlist(new_schcat, "4") & mi(schcat)
replace schcat = 5 if inlist(new_schcat, "5", "6", "7", "8") & mi(schcat)
drop new_schcat

replace water_any = 0 if new_water == "5" & mi(water_any)
replace water_any = 1 if inlist(new_water, "1", "10", "11", "12", "13", "14", "2") | inlist(new_water, "3", "4", "6")
drop new_water

ren new_enr_all_hs enr_hs

/* keep rural places only */
bys vilcd: egen max_rural = max(rural)
drop if max_rural == 0
drop max_rural

/* keep only vars that have been carefully combined, drop others */
keep vilcd schcd year enr_hs enr_g enr_b enr_p enr_up enr_up_b enr_up_g enr_p_b enr_p_g enr_total elec appear7 pass7 m607  schcat rural 

compress
save $tmp/dise-clean, replace

