global dise2016 ~/iec2/dise/dise-2016
cd $dise2016
cap mkdir $tmp/dise

/*******************************************/
/* CONVERT ALL EXCEL FILES TO STATA FORMAT */
/*******************************************/

/* loop over all years of data (recent years first for rapid analysis */
foreach y in 2011-2012 2012-2013 2013-2014 2014-2015 2015-2016 2005-2006 2006-2007 2007-2008 2008-2009 2009-2010 2010-2011 {
  qui cd `y'

  /* get list of subfolders */
  local folders: dir . dirs "*"

  /* loop over subfolders (state names) */
  di `"`folders'"'
  foreach folder in `folders' {

    /* get clean folder name */
    local state_name = subinstr("`folder'", " ", "-", .)
    disp_nice "Beginning `state_name'-`y'"
    
    qui cd "`folder'"

    /* get file list in this folder */
    local files: dir . files "*.xls*"

    /* loop over the file list */
    foreach excel_file in `files' {

      /* skip file types that we're not using for the moment */
      if (strpos("`excel_file'", "Repeaters") | strpos("`excel_file'", "OBCE") | strpos("`excel_file'", "Disabled") | strpos("`excel_file'", "OBCE") | strpos("`excel_file'", "RTE") | strpos("`excel_file'", "STEnr") | strpos("`excel_file'", "Teachers") ) {
        di "Skipping `excel_file' -- ignored file type..."
        continue
      }
      
      /* get a clean output filename */
      local filename = subinstr("`excel_file'", " ", "-", .)
      local filename = subinstr("`filename'", ".xlsx", "", .)
      local filename = subinstr("`filename'", ".xls", "", .)
      local filename = "$tmp/dise/`y'-`state_name'-`filename'"
      
      /* skip files that exist already */
      cap confirm file `filename'.dta
      if !_rc {
        di "Skipping `excel_file' -- file already exists..."
        continue
      }
      
      di "Processing `filename'..."

      /* open the file */
      cap import excel using "`excel_file'", clear firstrow

      /* if it failed (due to a buggy file), store the file, move on */
      if _rc {
        di "`excel_file' could not be loaded. Logging error and skipping..."
        append_to_file using $dise2016/corrupt_files.txt, s("`excel_file'")
        continue
      }

      /* save it to a flat .dta in /scratch/pn/dise */
      save `filename', replace
    }
    
    qui cd ..
  }
  
  qui cd ..
}


/********************************************************/
/* APPEND ALL STATA FILES INTO A SET OF MASTER DATASETS */
/********************************************************/

/* loop over all file types of interest */
cd $dise2016
foreach type in Facility General SCEnrolment TotalEnrolment Basic {

  /* create a single file containing everything from this type */
  clear
  gen year = ""
  gen dise_state = ""
  
  /* use the same looping structure to get the full set of filenames and states */
  foreach y in 2011-2012 2012-2013 2013-2014 2014-2015 2015-2016 2005-2006 2006-2007 2007-2008 2008-2009 2009-2010 2010-2011 {
    qui cd `y'
  
    /* get list of subfolders */
    local folders: dir . dirs "*"
  
    /* loop over subfolders (state names) */
    di `"`folders'"'
    foreach folder in `folders' {
  
      /* get clean folder name */
      local state_name = subinstr("`folder'", " ", "-", .)
      
      qui cd "`folder'"
  
      /* get file list in this folder that match this type */
      local files: dir . files "*`type'*.xls*"
  
      /* loop over the file list */
      foreach excel_file in `files' {
  
        /* skip file types that we're not using for the moment */
        if (strpos("`excel_file'", "Repeaters") | strpos("`excel_file'", "OBCE") | strpos("`excel_file'", "Disabled") | strpos("`excel_file'", "OBCE") | strpos("`excel_file'", "RTE") | strpos("`excel_file'", "STEnr") | strpos("`excel_file'", "Teachers") ) continue
  
        /* get a clean output filename */
        local filename = subinstr("`excel_file'", " ", "-", .)
        local filename = subinstr("`filename'", ".xlsx", "", .)
        local filename = subinstr("`filename'", ".xls", "", .)
        local filename = "$tmp/dise/`y'-`state_name'-`filename'"
        
        /* append the file to what we currently have open (for now, skip if it doesn't exist) */
        cap confirm file `filename'.dta
        if _rc continue
        di "Appending `type': `filename'..."
        qui append using `filename'
  
        /* set the year, state and type for this append */
        qui replace dise_state = "`state_name'" if mi(year)
        qui replace year = "`y'" if mi(year)
      }
      qui cd ..
    }
    qui cd ..
  }

  /* save the master type file */
  save $tmp/dise-new-`type', replace
}

