global out ~/iec/output/dise

/* use default stata scheme */
discard
set scheme s2color

/******************************/
/* road completion line graph */
/******************************/
use ~/iec2/working/pmgsy_working3_small, clear

keep comp_year
keep if inrange(comp_year, 2001, 2015)

gen number = 1
collapse (sum) number, by(comp_year)

label var number "Number of new roads"

graph bar number, over(comp_year, label(labsize(vsmall))) graphregion(color(white)) ytitle("Number of new roads") name(road_by_year, replace) bar(1, color(gs8))
graphout fig_road_by_year_new, pdf large

/*********************************/
/* table showing total by state  */
/*********************************/
use ~/iec2/working/pmgsy_working3_small, clear

keep if inrange(comp_year, 2001, 2015)

keep pc01_state_id 
get_state_names

gen number = 1
collapse  (sum) number, by(pc01_state_name)
replace pc01_state_name = proper(pc01_state_name)

graph hbar number, over(pc01_state_name) graphregion(color(white)) ytitle("Number of new roads") name(road_by_state, replace) bar(1, color(gs8))
graphout fig_road_by_state_new, pdf

/*******************************************/
/* FIRST STAGE GRAPH, 500 and 1000 cutoffs */
/*******************************************/
use ~/iec2/working/pmgsy_working3, clear

keep if pc01_vd_app_pr == 0 | con00 == 0
keep if inrange(pc01_pca_tot_p, 100, 1500)
drop if road_new == 0

keep pc01_state_name r2011 pc01_pca_tot_p
egen xq = cut(pc01_pca_tot_p), at(100(25)1500)

keep if inlist(pc01_state_name, "madhya pradesh", "rajasthan", "chhattisgarh", "gujarat", "orissa")
label var pc01_pca_tot_p "Village Population (2001 Population Census)"
label var r2011 "Road Built Before October 2011"

binscatter r2011 pc01_pca_tot_p, mcolor(black) xline(500 1000, lcolor(gs10)) linetype(none) xq(xq) graphregion(color(white)) xtitle("Village Population (2001 Population Census)") ytitle("Road Built Before October 2011") name(fs1, replace)
graphout fig_full_first_stage, pdf

/* count number of points, divide by 56 ((1500-100)/25 for xq25) to get points per bin */
count if !mi(r2011) & !mi(pc01_pca_tot_p)
di r(N) / 56


/*********************/
/* RD GRAPHS, POOLED */
/*********************/
use $tmp/dise_rd_table_data_new, clear

keep if state_sample == 1

rd r2011 pop_rd if inrange(year, 2011, 2015) & rd_band_4_, degree(1) bw bins(50) msize(small) xtitle("Village Population minus Treatment Threshold") ytitle("Road Built Before October 2011") name(fs2) cluster(svgroup)
graphout fig_first_stage_pooled_new, large

/* count number of points, divide by 50 ((500)/10 for xq25) to get points per bin */
count if !mi(r2011) & !mi(pop_rd) & rd_band_4_
di r(N) / 50

/* REDUCED FORM */
rd ln_enr_up pop_rd if inrange(year, 2011, 2015) & band, bins(44) absorb(dist_high_fe) control(pc01_pca_tot_p ln_enr_up_2002 ln_enr_p_2002 schcnt_2002) degree(1) bw msize(small) xtitle("Village Population minus Treatment Threshold") ytitle("Road Built Before October 2011") name(fs2) cluster(svgroup)
graphout fig_reduced_form_pooled_new, large pdf

rd ln_enr_p pop_rd if inrange(year, 2011, 2015) & band, bins(44) absorb(dist_high_fe) control(pc01_pca_tot_p ln_enr_p_2005 ln_enr_p_2005 schcnt_2005) degree(1) bw msize(small) xtitle("Village Population minus Treatment Threshold") ytitle("Road Built Before October 2011") name(fs2) cluster(svgroup)
graphout enr_p, large

/*******************/
/* RD MCCRARY TEST */
/*******************/
use $tmp/dise_rd_table_data_new, clear
keep if state_sample == 1
drop if pop_rd == 250

/* get analysis sample */
areg ln_enr_up t left right ln_enr_up_2005 if rd_band_4_, absorb(dist_high_fe)
keep if e(sample)

/* pooled 500 1000 */
do ~/iecmerge/include/dc_density.do
dc_density pop_rd if year == 2011 & rd_band_4_ == 1 & inrange(pop_rd, -249, 249), breakpoint(0) b(1) generate(Xj Yj r0 fhat se_fhat) xtitle("Population minus Eligibility Threshold") ytitle("Density")
drop Xj Yj r0 fhat se_fhat
graphout mccrary_new, pdf

histogram pop_rd, start(-250) width(10) xline(0, lcolor(black)) graphregion(color(white)) color(gs8) lcolor(black) xtitle("Population minus Eligibility Threshold")
graphout mccrary_hist_new, pdf

