/***********************************************************************************/
/* program dise_clean_common : Take cleaning steps that apply to all dise datasets */
/***********************************************************************************/
cap prog drop dise_clean_common
prog def dise_clean_common
{
  drop if inlist(trim(dise_state), "NORTH-EASTERN-STATES")

  /* combine AC YEARS */
  combine_vars AC_YEAR acyear, gen(dise_year)
  assert substr(dise_year, 1, 4) == substr(year, 1, 4)
  drop dise_year
  combine_vars School_Code SCHCD SCHOOL_CODE Schcd, gen(schcd)
  gen vilcd = substr(schcd, 1, 9)
}
end
/* *********** END program dise_clean_common ***************************************** */

/**********************************************************************************/
/* program dise_clean_enr : Clean generic enrollment dataset                      */
/**********************************************************************************/
cap prog drop dise_clean_enr
prog def dise_clean_enr
{
  syntax, caste(string)
  
  /* destring all enrollment numbers */
  destring enr*, replace
  
  /* create log and total enrollment variables of interest */

  /* NOTE: REQUIRES SORT ORDER TO BE b1, g1, b2, g2, ... b12, g12 */
  
  /* (primary / upper prmiary / HS) * (boys / girls) */
  egen enr_`caste'_p =     rowtotal(enr_`caste'_b1-enr_`caste'_g5)
  egen enr_`caste'_up =    rowtotal(enr_`caste'_b6-enr_`caste'_g8)
  egen enr_`caste'_hs =    rowtotal(enr_`caste'_b9-enr_`caste'_g12)
  egen enr_`caste' = rowtotal(enr_`caste'_b1-enr_`caste'_g8)
  
  /* log enrollments */
  gen ln_enr_`caste'_p = ln(enr_`caste'_p + 1)
  gen ln_enr_`caste'_up = ln(enr_`caste'_up + 1)
  gen ln_enr_`caste'_hs = ln(enr_`caste'_hs + 1)
  gen ln_enr_`caste' = ln(enr_`caste' + 1)
  
  /* repeat with boys and girls separated */
  foreach v in b g {
    egen enr_`caste'_p_`v'  = rowtotal(enr_`caste'_`v'1 enr_`caste'_`v'2 enr_`caste'_`v'3 enr_`caste'_`v'4 enr_`caste'_`v'5)
    egen enr_`caste'_up_`v' = rowtotal(enr_`caste'_`v'6 enr_`caste'_`v'7 enr_`caste'_`v'8)
    
    egen enr_`caste'_`v'    = rowtotal(enr_`caste'_p_`v' enr_`caste'_up_`v')
    
    /* log enrollments */
    gen ln_enr_`caste'_p_`v'  = ln(enr_`caste'_p_`v' + 1)
    gen ln_enr_`caste'_up_`v' = ln(enr_`caste'_up_`v' + 1)
    gen ln_enr_`caste'_`v'    = ln(enr_`caste'_`v' + 1)
  }
}
end
/* *********** END program dise_clean_enr ***************************************** */

/*************************************************************************************************/
/* program combine_vars : combine variables when different varnames were used for the same thing */
/*    example: combine_vars electric Electric_yn ELECTRIC_YN, gen(elec)                          */
/*************************************************************************************************/
cap prog drop combine_vars
prog def combine_vars
{
  syntax anything, GENerate(string)

  tokenize `anything'

  gen `generate' = ""
  
  forval i = 1/20 {
    if mi("``i''") continue

    /* skip variable if it doesn't exist */
    cap confirm variable ``i''
    if _rc {
      di "Skipping ``i'': not found in data."
      continue
    }

    cap assert mi(`generate') if !mi(``i'')
    if _rc {
      di "Assertion failed: assert mi(`generate') if !mi(``i'')"
      error 123
    }

    replace `generate'  = ``i'' if !mi(``i'')
  }

  /* if we made it this far without errors (i.e. all assertions successful), drop all original variables */
  forval i = 1/20 {
    if mi("``i''") continue
    cap drop ``i''
  }  
}
end
/* *********** END program combine_vars ***************************************** */

