use $tmp/dise_table_data_new, clear

global cluster cluster(svgroup)
keep if !mi(comp_year)

/* set to all_comp sample */
reghdfe ln_enr_up treatment_comp if all_comp == 1, absorb(svgroup sygroup) 
keep if e(sample)

/* tag villages */
tag pc01_state_id pc01_village_id 

save $tmp/perm, replace
set seed 1

/* put header into output file */
cap file close fh
file open fh using $tmp/dise_perm_test_new.csv, write replace
file write fh "beta,se,p,n,text" _n
file close fh

use $tmp/perm, clear

/* run 1000 permutations */
forval i = 1/1000 {
  
  cap drop treatment_comp_random
  cap drop comp_year_random
  
  /* generate comp_year at random */
  qui {
    
    gen tmp = floor(uniform() * 14) + 2002 if svtag
    bys pc01_state_id pc01_village_id: egen comp_year_random = max(tmp)
    drop tmp
  
    /* generate random treatment indicator */
    gen treatment_comp_random = year >= comp_year_random if !mi(year)
    
    /* run standard regression */
    reghdfe ln_enr_up treatment_comp_random if all_comp == 1, absorb(svgroup sygroup) $cluster
  }
  
  /* store estimate of interest */
  append_est_to_file using $tmp/dise_perm_test_new.csv, b(treatment_comp_random) suffix(`i')
  disp_est, b(treatment_comp_random) title(`i')
}

/* generate estimate graph */
insheet using $tmp/dise_perm_test_new.csv, clear names
replace beta = -beta
histogram beta, xline(0.067) graphregion(color(white)) fraction color(gs8) lcolor(black) xtitle("Treatment Effect")
graphout permutation_histogram_new, pdf large

