global dise_inf_vars toilet_any elec med board lib play ramp computer water_tap water_taporpump bndrywall_pucca bndrywall_none water_any
global dise_enr_vars enr_total enr_up enr_b enr_g enr_p enr_up_b enr_up_g enr_p_b enr_p_g
global dise_exam_vars appear5 pass5 m605 appear7 pass7 m607 enr5 enr7 enr_cl4 enr_cl5 enr_cl7 enr_cl8 appear5 pass5 m605

/*****************************************/
/* create dise electrification variables */
/*****************************************/
use $tmp/dise-clean, clear

/* drop _merge == 2: pop census but not DISE:  no enrollment data */
/* drop _merge == 1: DISE data but not pop census-- unusable */

/* generate number of upper primary schools and upper prim school with positive enrollment */
/* (positive enrollment is how they defined primary or upper primary) */
gen schcnt_up = inlist(schcat, 2, 3, 4, 5) 
gen schcnt_p_only = schcat == 1
gen schcnt_nz = !mi(enr_total) & enr_total != 0
gen schcnt = 1

label var schcnt_up      "Number of upper primary schools in village"
label var schcnt_p      "Number of primary-only schools in village"
label var schcnt_nz      "Number of non-zero enrollment schools in village"
label var schcnt      "Number of schools in village (DISE)"

/* set as school panel */
group schcd
group vilcd
group vilcd year
sort sgroup year
xtset sgroup year

/* create a pre-collapse indicator for any missing enrollment in this village */
gen mi_enr_total = mi(enr_total)

/* keep vars relevant for analysis only */
compress
save $tmp/dise_precollapse.dta, replace

/******************************/
/* collapse to village level  */
/******************************/

/* collapse */
global dise_collapse_sum_vars $dise_enr_vars appear* pass* m60* schcnt* 
global dise_collapse_first_vars 

/* Collapse to village level, using vilcd, since some 1:m vilcd:pc01_village_id dups
  that we want to take out later. */
keep mi_enr_total $dise_collapse_sum_vars $dise_collapse_mean_vars $dise_collapse_first_vars  year vilcd
sort vilcd year
collapse_save_labels

collapse (sum) mi_enr_total $dise_collapse_sum_vars           ///
         (mean) $dise_collapse_mean_vars         ///
         (firstnm) $dise_collapse_first_vars, by(vilcd year)

collapse_apply_labels
compress

save $tmp/dise-collapsed, replace

/************************/
/* Bring in PC datasets */
/************************/

/* merge to pc01 village key */
merge m:1 vilcd using $dise/dise_village_key, keepusing(pc01_state_id pc01_village_id dise_match_source) nogen keep(master match)

/* bring in PMGSY road treatment year */
merge m:1 pc01_state_id pc01_village_id using $tmp/pmgsy_short, keep(master match)

/* bring in PC01/PC11 vars of interest.  */
global dise_pc01_pca_vars pc01_district_id pc01_subdistrict_id pc01_pca_tot_p pc01_ill_share litrate_p01 pc01_pca_f_sc pc01_pca_m_sc
global dise_pc01_vd_vars pc01_vd_edu_fac pc01_vd_p_sch pc01_vd_rang_p_sch pc01_vd_m_sch pc01_vd_rang_m_sch pc01_vd_app_pr pc01_vd_dist_town pc01_vd_power_supl pc01_vd_area pc01_vd_area_na_cu 
global dise_pc11_vars litrate_p11 litrate_m11 litrate_f11 pc11_pca_tot_p
merge m:1 pc01_state_id pc01_village_id using $pc01/pc01r_pca_clean, keep(master match) nogen keepusing($pc01_pca_vars)
merge m:1 pc01_state_id pc01_village_id using $pc01/pc01_vd_clean,   keep(master match) nogen keepusing($pc01_vd_vars)
merge m:1 pc01_state_id pc01_village_id using $pc11/pc11_pca_pc01,   keep(master match) nogen keepusing($pc11_vars) 

/* bring in PC11 village identifiers */
merge m:1 pc01_state_id pc01_village_id using $tmp/pc11_village_key_unique, keepusing(pc11_state_id pc11_village_id) nogen keep(master match)

/* create pc01 state identifiers for unmatched villages [of which there are none] */
replace pc01_state_id = substr(vilcd, 1, 2) if mi(pc01_state_id)

/****************************************/
/* Create some control vars of interest */
/****************************************/

/* save village-level combined dataset */
save $tmp/dise_village_unclean, replace

/* remove pc01 duplicates-- multiple vilcds matched to a single pc01_state_id pc01_village_id */
ddrop pc01_state_id pc01_village_id year if !mi(pc01_village_id) & !mi(pc01_state_id)

/* create log enrollment variables */
foreach v in enr_total enr_g enr_b enr_p enr_up /*enr_io enr_ic */ enr_up_b enr_up_g enr_p_b enr_p_g {
  gen ln_`v' = ln(`v' + 1)
}

/* create numeric village identifier for fixed effects and clusters */
group vilcd

/* set as village-year time series */
sort vgroup year
xtset vgroup year, yearly

/* create enrolment and school growth variables */
gen enr_growth = enr_total / L.enr_total - 1
gen ln_enr_growth = ln_enr_total - L.ln_enr_total
gen ln_enr_up_growth = ln_enr_up - L.ln_enr_up

/* generate log population */
gen ln_pop01 = ln(pc01_pca_tot_p)

/*********************/
/* SET OUTLIER FLAGS */
/*********************/

/* drop villages with outlier populations */
drop if !inrange(pc01_pca_tot_p, 100, 5000) & !mi(pc01_pca_tot_p)

/* generate enrolment in 2002 and 2005 as fraction of PC01 2001 population  (2005=first year with complete data) */
foreach y in 2002 2005 {
  gen tmp = enr_total / pc01_pca_tot_p if year == `y'
  bys vgroup: egen enr_over_pop_`y' = max(tmp)
  drop tmp
}

/* drop places with no data */
drop if pc01_state_name == "kerala"

/* create flag variables for severe and bad outliers */
gen severe = 0
gen bad = 0

/* flag unreasonable log growth observations (villages changing by more than an order of magnitude in one year) */
replace bad = 1 if !inrange(ln_enr_growth, -1, 1) & !mi(ln_enr_growth)

/* flag levels indicating >200% or <-66% */
replace bad = 1 if enr_growth > 2 & !mi(enr_growth)
replace bad = 1 if enr_growth < -.66 & !mi(enr_growth)

/* FLAG LESS SEVERE OUTLIERS */
/* flag observations with implausible enrolment over population (roughly 98th percentile) -- 95th is .55  */
replace severe = 1 if enr_over_pop_2005 > 1  & !mi(enr_over_pop_2005)
replace bad = 1    if enr_over_pop_2005 > .6 & !mi(enr_over_pop_2005)

/* drop severe outliers */
drop if severe == 1  

/* set baseline enrollment levels */
foreach v in enr_total enr_up enr_p ln_enr_total ln_enr_up ln_enr_p schcnt schcnt_nz {
  foreach y in 2002 2005 {
    gen tmp = `v' if year == `y'
    bys vgroup: egen `v'_`y' = max(tmp)
    drop tmp
  }
}

/* create some additional control vars */
gen sc_share = pc01_pca_p_sc / pc01_pca_tot_p

/* SAVE DISE PANEL DATASET */
sort vgroup year
save $dise/dise_village_new_clean, replace

/* save short version of this dataset */
drop vilcd *name*
ren pc01_pca_tot_p pop
ren pc01_vd_app_pr app_pr
drop pc01_pca* pc01_vd* pc11_pca*
drop lati-longi pmgsy_state_id irr_share-_merge *growth ln_pop01 severe
saveold $dise/dise_village_new_short, replace 

