
/***********************************/
/* TABLES WITH EXAMINATION RESULTS */
/***********************************/

/***********************/
/* prepare exam sample */
/***********************/
use $tmp/dise_table_data, clear

/* yvars of interest: 3 exam variables: appear7, pass7, m607 */

/* rename high score variable to make more sensible */
rename m607 win7
rename m605 win5

global exam_vars appear7 pass7 win7

/******************/
/* Exam variables */
/******************/

gen exam_sample = 1

/* no exam data before 2005, so remove from sample */
replace exam_sample = 0 if dise_year < 2005

/* generate class 5, 7 enrollment */
egen enr_c5 = rowtotal(enr_scg5 enr_scb5)
egen enr_c6 = rowtotal(enr_scg6 enr_scb6)
egen enr_c7 = rowtotal(enr_scg7 enr_scb7)
egen enr_c8 = rowtotal(enr_scg8 enr_scb8)

/* identify exam takers as function of class 7 enrollment */
foreach v in appear pass win {
  gen `v'5_over_enr = `v'5 / enr_c5
  gen `v'7_over_enr = `v'7 / enr_c7
}

/* restrict to exam takers double enrollment */
foreach v in appear pass win {
  replace `v'5 = . if `v'5_over_enr > 2 & !mi(`v'5_over_enr)
  replace `v'7 = . if `v'7_over_enr > 2 & !mi(`v'7_over_enr)
}

/* create log exam vars */
foreach v in appear pass win {
  gen ln_`v'5 = ln(`v'5 + 1)
  gen ln_`v'7 = ln(`v'7 + 1)
}

/* mark villages, subdistricts, districts with no exam takers in any period */
bys v_fe: egen max_appear_v = max(appear7)
bys sdsgroup: egen max_appear_subd = max(appear7)
bys sdgroup: egen max_appear_dist = max(appear7)

replace exam_sample = 0 if dise_year > 2009

replace exam_sample = 0 if !inrange(comp_year, 2005, 2009)
keep if exam_sample == 1

save $tmp/dise_exams, replace

/**********************/
/* panel exam results */
/**********************/
use $tmp/dise_exams, clear

/* require all data so column sample sizes line up */
keep if !mi(ln_appear7) & !mi(ln_pass7) & !mi(ln_win7)

fvset base 145 dsgroup
eststo clear

foreach v in ln_appear7 ln_pass7 ln_win7 {
  eststo: reghdfe `v' i.dise_year##i.sgroup treatment_comp if all10_comp == 1, absorb(vgroup) cluster(vgroup)
}
label var treatment_comp "New Road"

global prefoot "\hline State-Year F.E.              & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E.        & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Panel Sample              & Balanced & Balanced & Balanced \\ " "\hline "
estout_default using $out/table_panel_exam, keep(treatment_comp) prefoot($prefoot) eparams(${estout_params_no_p})
estmod_header  using $out/table_panel_exam.tex, cstring(" & \underline{Exam Taken} & \underline{Exam Passed} & \underline{High Exam Score}")

/**********************/
/* repeat for class 5 */
/**********************/
use $tmp/dise_exams, clear

/* require all data so column sample sizes line up */
keep if !mi(ln_appear5) & !mi(ln_pass5) & !mi(ln_win5)

fvset base 145 dsgroup
eststo clear

foreach v in ln_appear5 ln_pass5 ln_win5 {
  eststo: reghdfe `v' i.dise_year##i.sgroup treatment_comp if all10_comp == 1, absorb(vgroup) cluster(vgroup)
}
label var treatment_comp "New Road"

global prefoot "\hline State-Year F.E.              & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E.        & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Panel Sample              & Balanced & Balanced & Balanced \\ " "\hline "
estout_default using $out/table_panel_exam_5, keep(treatment_comp) prefoot($prefoot) 
estmod_header  using $out/table_panel_exam_5.tex, cstring(" & \underline{Exam Taken} & \underline{Exam Passed} & \underline{High Exam Score}")

