/********************************************/
/* TABLE 2: NEW MAIN TABLE -- ONE SPEC ONLY */
/********************************************/
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

/* Column: balanced panel */
eststo: reghdfe ln_enr_up treatment_comp if all_comp == 1, absorb(vgroup sygroup) $cluster

/* Column: girls only */
eststo: reghdfe ln_enr_up_g  treatment_comp  if all_comp == 1, absorb(vgroup sygroup) $cluster

/* Column: boys only */
eststo: reghdfe ln_enr_up_b  treatment_comp  if all_comp == 1, absorb(vgroup sygroup) $cluster

/* Column: balanced, levels */
eststo: reghdfe enr_up  treatment_comp    if all_comp == 1, absorb(vgroup sygroup) $cluster

/* Column: levels, girls only */
eststo: reghdfe enr_up_g  treatment_comp  if all_comp == 1, absorb(vgroup sygroup) $cluster

/* Column: levels, boys only */
eststo: reghdfe enr_up_b  treatment_comp  if all_comp == 1, absorb(vgroup sygroup) $cluster

label var treatment_comp "New Road"
global prefoot "\hline"
estout_default using $out/table_panel_new, keep(treatment_comp) prefoot($prefoot)
estmod_header  using $out/table_panel_new.tex, cstring("Dependent Variable & All, log & Girls, log & Boys, log & All, levels & Girls, levels & Boys, levels")

/* get treatment difference for boys vs girls */
qui eststo boys: reg ln_enr_up_b i.sygroup treatment_comp  if all_comp == 1, absorb(vgroup)
qui eststo girls: reg ln_enr_up_g i.sygroup treatment_comp  if all_comp == 1, absorb(vgroup) 
qui suest boys girls, vce(cluster vgroup)
test [boys_mean]treatment_comp = [girls_mean]treatment_comp

/* get level treatment difference for boys vs girls */
eststo clear
eststo one: reg enr_up_b i.sygroup treatment_comp  if all_comp == 1, absorb(vgroup) 
eststo two: reg enr_up_g i.sygroup treatment_comp  if all_comp == 1, absorb(vgroup) 
suest one two, vce(cluster vgroup)
test [one_mean]treatment_comp = [two_mean]treatment_comp

/*********************************************/
/* TABLE 3: ROBUSTNESS OF MAIN SPECIFICATION */
/*********************************************/
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

/* COLUMN: add village linear time trend  */
eststo: reghdfe ln_enr_up i.sygroup treatment_comp  if all_comp == 1, absorb(vgroup##c.year) $cluster

/* COLUMN: interact baseline characteristics with year dummies */
/* create global var with fixed effect interactions */
global interactions
global vlist irr_share pc01_vd_p_sch ln_enr_up_2002 litrate_p01 sc_share pc01_vd_dist_town pc01_pca_tot_p
foreach v in $vlist {
  global interactions $interactions c.`v'##i.year 
}
eststo: reghdfe ln_enr_up i.sygroup $interactions treatment_comp  if all_comp == 1, absorb(i.vgroup) $cluster

/* COLUMN: unbalanced, road at some point */
eststo: reghdfe ln_enr_up treatment_comp  if unbal == 1, absorb(vgroup sygroup) $cluster

/* COLUMN: unbalanced with village time trend */
eststo: reghdfe ln_enr_up treatment_comp  if unbal == 1, absorb(vgroup##c.year sygroup) $cluster

/* COLUMN: Post-2005 balanced */
eststo: reghdfe ln_enr_up treatment_comp if all_comp == 1 & year >= 2005, absorb(vgroup sygroup) $cluster

/* COLUMN: Super-balanced on relative time */
gen rt = year - (comp_year)
eststo: reghdfe ln_enr_up treatment_comp  if inrange(rt, -4, 4) & inrange(comp_year, 2004, 2012), absorb(vgroup sygroup) $cluster

label var treatment_comp "New Road"

global prefoot "\hline State-Year F.E.              & Yes & Yes & Yes & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E.        & Yes & Yes & Yes & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village Time Trends  & Yes & No & No & Yes  & No & No \\ " 
global prefoot $prefoot "       Baseline Vars * Year Dummies & No & Yes & No & No & No & No  \\ " "\hline "
global prefoot $prefoot "       Panel Sample & Balanced & Balanced & Unbalanced & Unbalanced & Balanced Post-2004 & 4 Years Pre/Post  \\ " "\hline "

estout_default using $out/table_panel_robust_new, keep(treatment_comp) prefoot($prefoot)

/************************************/
/* TABLE 7: TREATMENT HETEROGENEITY */
/************************************/
/* run interaction regs */
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

eststo: reghdfe ln_enr_up treatment_comp                    if all_comp == 1, absorb(vgroup inter_fe) $cluster
eststo: reghdfe ln_enr_up treatment_comp t_wg               if all_comp == 1, absorb(vgroup inter_fe) $cluster
eststo: reghdfe ln_enr_up treatment_comp t_ret              if all_comp == 1, absorb(vgroup inter_fe) $cluster
eststo: reghdfe ln_enr_up treatment_comp t_poor            if all_comp == 1, absorb(vgroup inter_fe) $cluster
eststo: reghdfe ln_enr_up treatment_comp t_wg t_ret t_poor if all_comp == 1, absorb(vgroup inter_fe) $cluster

label var t_wg           "New Road * High Opportunity Cost Effect"
label var t_ret          "New Road * High Returns to Education Effect"
label var t_poor        "New Road * High Income/Liquidity Effect"
label var treatment_comp "New Road"
global prefoot          "\hline State-Year F.E.  & Yes & Yes & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E.     & Yes & Yes & Yes & Yes & Yes \\ "
global prefoot $prefoot "       Panel Sample  & Balanced & Balanced & Balanced & Balanced & Balanced  \\ " "\hline "
estout_default using $out/table_panel_interaction_new, keep(treatment_comp t_wg t_ret t_poor) prefoot($prefoot)
estout, $estout_params_txt keep(treatment_comp t_wg t_ret t_poor) 

/***********************************************/
/* TABLE 8 TRIPLE INTERACTION, REGRESSION ONLY */
/***********************************************/
label var treatment_comp "Road"
label var t_wg "Road * Wage Gap"
label var t_ret "Road * Return Gap"
label var t_poor "Road * Poor"
label var t_wg_ret "Road * Wage Gap * Return Gap"
label var t_ret_poor "Road * Return Gap * Poor"
label var t_wg_poor "Road * Wage Gap * Poor"
label var t_wg_ret_poor "Road * Wage Gap * Return Gap * Poor"
global prefoot          "\hline State-Year F.E.  & Yes \\ " 
global prefoot $prefoot "       Village F.E.     & Yes \\ "
global prefoot $prefoot "       Panel Sample  & Balanced  \\ " "\hline "
estout_default using $out/table_panel_triple_inter_new, prefoot($prefoot)
estout, $estout_params_txt 

/* run linear combinations to see where treatment effects are positive */
cap prog drop do_it
prog def do_it
{
  preserve
  keep if e(sample)
  cap drop svtag
  tag pc01_state_id pc01_village_id
  count if svtag
  local ALL = `r(N)'
  
  qui lincom treatment_comp
  local b = `r(estimate)'
  qui test treatment_comp = 0
  local p = `r(p)'
  qui count if unskilled_wage_gap_high == 0 & ret_gap_high == 0 & village_poor_high == 0 & svtag
  local n = `r(N)'
  di "0-0-0: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_wg 
  local b = `r(estimate)'
  qui test treatment_comp + t_wg  = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 1 & ret_gap_high == 0 & village_poor_high == 0 & svtag
  local n = `r(N)'
  di "1-0-0: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_ret 
  local b = `r(estimate)'
  qui test treatment_comp + t_ret  = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 0 & ret_gap_high == 1 & village_poor_high == 0 & svtag
  local n = `r(N)'
  di "0-1-0: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_ret + t_wg + t_wg_ret
  local b = `r(estimate)'
  qui test treatment_comp + t_ret + t_wg + t_wg_ret = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 1 & ret_gap_high == 1 & village_poor_high == 0 & svtag
  local n = `r(N)'
  di "1-1-0: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_poor
  local b = `r(estimate)'
  qui test treatment_comp + t_poor = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 0 & ret_gap_high == 0 & village_poor_high == 1 & svtag
  local n = `r(N)'
  di "0-0-1: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_wg + t_poor
  local b = `r(estimate)'
  qui test treatment_comp + t_wg + t_poor = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 1 & ret_gap_high == 0 & village_poor_high == 1 & svtag
  local n = `r(N)'
  di "1-0-1: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_ret + t_ret_poor + t_poor
  local b = `r(estimate)'
  qui test treatment_comp + t_ret + t_ret_poor + t_poor = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 0 & ret_gap_high == 1 & village_poor_high == 1 & svtag
  local n = `r(N)'
  di "0-1-1: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  qui lincom treatment_comp + t_ret + t_wg + t_wg_ret + t_poor + t_ret_poor + t_wg_poor + t_wg_ret_poor
  local b = `r(estimate)'
  qui test treatment_comp + t_ret + t_wg + t_wg_ret + t_poor + t_ret_poor + t_wg_poor + t_wg_ret_poor = 0
  local p = `r(p)'
  qui  count if unskilled_wage_gap_high == 1 & ret_gap_high == 1 & village_poor_high == 1 & svtag
  local n = `r(N)'
  di "1-1-1: " %6.3f `b' "  n=" %8.0f `n'  "  " %5.2f (`n'/`ALL') ", p=" %5.2f `p'
  
  
  restore
}
end

do_it

/*******************/
/* APPENDIX TABLES */
/*******************/

/*******************************************/
/* TABLE A2 -- DISTRICT-YEAR FIXED EFFECTS */
/*******************************************/
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

/* Column: balanced panel */
eststo: reghdfe ln_enr_up treatment_comp if all_comp == 1, absorb(vgroup sdygroup) $cluster

/* Column: girls only */
eststo: reghdfe ln_enr_up_g  treatment_comp  if all_comp == 1, absorb(vgroup sdygroup) $cluster

/* Column: boys only */
eststo: reghdfe ln_enr_up_b  treatment_comp  if all_comp == 1, absorb(vgroup sdygroup) $cluster

/* Column: balanced, levels */
eststo: reghdfe enr_up  treatment_comp    if all_comp == 1, absorb(vgroup sdygroup) $cluster

/* Column: levels, girls only */
eststo: reghdfe enr_up_g  treatment_comp  if all_comp == 1, absorb(vgroup sdygroup) $cluster

/* Column: levels, boys only */
eststo: reghdfe enr_up_b  treatment_comp  if all_comp == 1, absorb(vgroup sdygroup) $cluster

label var treatment_comp "New Road"

global prefoot "\hline"
estout_default using $out/table_panel_district_fe_new, keep(treatment_comp) prefoot($prefoot)
estmod_header  using $out/table_panel_district_fe_new.tex, cstring("Dependent Variable & All, log & Girls, log & Boys, log & All, levels & Girls, levels & Boys, levels")


/***************************************************/
/* TABLE 6 -- IMPACT ON PRIMARY SCHOOL ENROLLMENT */
/***************************************************/
use $dise/dise_table_data_new_short, replace
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

/* Column 1: balanced panel */
eststo: reghdfe ln_enr_p  treatment_comp  if all_comp == 1, absorb(sygroup vgroup) $cluster

/* Column 2: village time trends */
eststo: reghdfe ln_enr_p  treatment_comp  if all_comp == 1, absorb(sygroup vgroup##c.year) $cluster

/* Column 3: unbalanced */
eststo: reghdfe ln_enr_p  treatment_comp  if unbal == 1, absorb(sygroup vgroup##c.year) $cluster

/* Columns 4-5: RD */
use $tmp/dise_rd_table_data_new, clear
keep if inrange(year, 2011, 2015) & abs(pop_rd) < 160
global controls ln_ec98_emp_all pc01_lit_rate 
eststo: areg ln_enr_p t left right $controls, absorb(dist_high_fe) cluster(vgroup)

/* Column 5: IV */
replace treatment_comp = got_road
eststo: ivregress 2sls ln_enr_p (treatment_comp=t) left right $controls i.dist_high_fe, vce(cluster vgroup)

/* label variables */
label var treatment_comp "New Road"
label var t "Above Population Threshold"

global prefoot "\hline" 
estout_default using $out/app_table_prim_new, order(treatment_comp t) keep(treatment_comp t) prefoot($prefoot)
estmod_header using $out/app_table_prim_new.tex, cstring("& \multicolumn{3}{c}{\underline{Panel}} & \underline{Reduced Form} & \underline{IV}")

/* binscatter primary result for referees */
rd ln_enr_p pop_rd if inrange(year, 2011, 2015), bins(40) degree(1) absorb(dist_high_fe) cluster(vgroup) control($controls) bw xtitle("Village Population minus Treatment Threshold") ytitle("Log Primary Enrollment, Mean 2011-2015")
graphout ref_fig_prim_rf_pooled_new, pdf

/*****************************************/
/* TABLE A5 -- HETEROGENEITY BY QUARTILE */
/*****************************************/
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

foreach v in ret_gap unskilled_wage_gap village_poor {
  sum `v', d
  gen `v'_q1 = `v' < `r(p25)'
  gen `v'_q2 = inrange(`v', `r(p25)', `r(p50)')
  gen `v'_q3 = inrange(`v', `r(p50)', `r(p75)')
  gen `v'_q4 = `v' > `r(p75)' & !mi(`v')
}

/* review quartile regression results */
cap erase $tmp/quartiles_new.csv
foreach v in ret_gap unskilled_wage_gap village_poor {
  if "`v'" == "ret_gap" {
    local s rg
  }
  else if "`v'" == "unskilled_wage_gap" {
    local s wg
  }
  else {
    local s poor
  }
  di "--------------------------"
  forval i = 1/4 {
    qui reghdfe ln_enr_up treatment_comp if all_comp == 1 & `v'_q`i' == 1, absorb(vgroup inter_fe3v) cluster(vgroup)
    disp_est, b(treatment_comp) title(`v'-`i')
    store_est_tpl using $tmp/quartiles_new.csv, coef(treatment_comp) name(`s'`i') all
  }
}

/* create quartiles table */
table_from_tpl, t(~/iecmerge/paul/dise/tpl/inter_quartiles_new.tex) r($tmp/quartiles_new.csv) o($out/table_inter_quartiles_new.tex)

/******************************/
/* TABLE A8: SPATIAL EFFECTS */
/******************************/
use $dise/dise_table_data_new_short, clear
eststo clear
global cluster cluster(vgroup)
keep if !mi(comp_year)

/* get enrollments in some radius */
merge 1:1 pc01_state_id pc01_village_id year using $tmp/dise_catchments, keep(master match) nogen

/* calculate log enrollment at 3km and 5km */
gen ln_enr_up_3km = ln(enr_up_3km + 1)
gen ln_enr_up_5km = ln(enr_up_5km + 1)

reghdfe ln_enr_up treatment_comp if all_comp == 1 & !mi(enr_up_5km), absorb(vgroup sygroup) $cluster

/* 3km radius log enrollment change */
eststo: reghdfe ln_enr_up_3km treatment_comp if all_comp == 1 & !mi(enr_up_5km), absorb(vgroup sygroup) $cluster

/* 5km radius log enrollment change */
eststo: reghdfe ln_enr_up_5km treatment_comp if all_comp == 1 & !mi(enr_up_5km), absorb(vgroup sygroup) $cluster

/* VILLAGE AREA PC: HIGH AND LOW */
/* set analysis sample */
reghdfe ln_enr_up treatment_comp if all_comp == 1, absorb(vgroup sygroup) $cluster
capdrop mark big_village area_pc median_area
gen mark = e(sample)

gen area_pc = vd_area / pc01_pca_tot_p
sum area_pc if mark & year == 2011, d
gen big_village = area_pc > `r(p50)' if !mi(area_pc)

/* low/high village area */
eststo: reghdfe ln_enr_up treatment_comp if unbal == 1 & big_village == 0, absorb(vgroup sygroup ) $cluster
eststo: reghdfe ln_enr_up treatment_comp if unbal == 1 & big_village == 1, absorb(vgroup sygroup ) $cluster

/* NEARBY UNSERVED KIDS */
reghdfe ln_enr_up treatment_comp if all_comp == 1 & !mi(p06_nom_3km), absorb(vgroup sygroup ) $cluster
keep if e(sample)

/* generate p06_nom in 2002 */
tag pc01_state_id pc01_village_id if !mi(p06_nom_3km)
gen share_unserved = p06_nom_3km / pc01_pca_tot_p
bys svgroup: egen share_unserved_2002 = max((year == 2002) * share_unserved)
sum share_unserved_2002 if svtag

/* above/below median unserved kids within 3km */
eststo: reghdfe ln_enr_up treatment_comp if all_comp == 1 & share_unserved_2002 < 0.5117005, absorb(vgroup sygroup ) $cluster
eststo: reghdfe ln_enr_up treatment_comp if all_comp == 1 & share_unserved_2002 > 0.5117005, absorb(vgroup sygroup ) $cluster

label var treatment_comp "New Road"

global prefoot "\hline State-Year F.E. & Yes & Yes & Yes & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Village F.E. & Yes & Yes & Yes & Yes & Yes & Yes \\ " 
global prefoot $prefoot "       Panel Sample & Balanced & Balanced & Balanced & Balanced & Balanced & Balanced  \\ " "\hline "
estout_default using $out/spatial_regs_new, keep(treatment_comp) prefoot("$prefoot") mlabel("3 km" "5 km" "Low" "High" "Low" "High")
estmod_header using $out/spatial_regs_new.tex, cstring(" & \multicolumn{2}{c}{\underline{Spillovers}} & \multicolumn{2}{c}{\underline{Village Area}} & \multicolumn{2}{c}{\underline{Nearby Eligible Kids}}")


/*******************************/
/* Table A4: PANEL VS RD */
/*******************************/

/* get RD sample list of villages */
use $tmp/dise_rd_table_data_new, clear
qui quireg ln_enr_up t left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 240, cluster(vgroup)
keep if e(sample)
drop if mi(got_road)
reg ln_enr_up t left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch if abs(pop_rd) < 240
keep if e(sample)
keep pc01_state_id pc01_village_id pop_rd
duplicates drop
save $tmp/rd_sample, replace

/* open panel and limit to RD spec */
use $dise/dise_table_data_new_short, clear
merge m:1 pc01_state_id pc01_village_id using $tmp/rd_sample, gen(merge_rd_panel)

eststo clear
global cluster cluster(vgroup)

/* main panel reg */
eststo: reghdfe ln_enr_up  treatment_comp  if all_comp == 1 & merge_rd_panel != 2 & !mi(comp_year), absorb(sygroup vgroup) $cluster

/* matched RD states only */
gen rd_states = 1 if all_comp == 1 & inlist(pc01_state_id, "08", "24", "21", "22", "23") & !mi(comp_year)
eststo: reghdfe ln_enr_up  treatment_comp  if rd_states == 1, absorb(sygroup vgroup) $cluster

/* RD matched villages only (but limited completion years) */
eststo: reghdfe ln_enr_up  treatment_comp  if all_comp == 1 & merge_rd_panel == 3 & !mi(comp_year), absorb(sygroup vgroup) $cluster
/* distribution of completion years */
tab comp_year if e(sample)

/* rd sample villages, but include untreated */
eststo: reghdfe ln_enr_up  treatment_comp  if all_comp == 1 & merge_rd_panel == 3, absorb(sygroup vgroup) $cluster

label var treatment_comp "New Road"
global prefoot "\hline"
estout_default using $out/table_rd_panel_comp, keep(treatment_comp) prefoot($prefoot)
estmod_header  using $out/table_rd_panel_comp.tex, cstring(" &  &  &  & RD Villages")
estmod_header  using $out/table_rd_panel_comp.tex, cstring("Dependent Variable & Full Sample & RD States & RD Villages & with Untreated")
