/*********************************************/
/* TABLE 4: RD FIRST STAGE, REDUCED FORM, IV */
/*********************************************/
use $tmp/dise_rd_table_data_new, clear

/* limit to the sample that has all variables needed */
qui quireg ln_enr_up t left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 200, cluster(vgroup)
keep if e(sample)

/**************************************************/
/* 1. coefplot: 3 bandwidths, 5 years plus pooled */
/**************************************************/
preserve
keep if inrange(year, 2010, 2015)
global f $tmp/iv_ests.csv
cap erase $f
append_to_file using $f, s(b,se,p,n,bandwidth,year,spec)
forval b = 120(40)200 {
  forval year = 2010/2015 {
    ivregress 2sls ln_enr_up (got_road=t) left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < `b' & year == `year', robust
    append_est_to_file using $f, b(got_road) s("`b',`year',iv")
  }
  /* pool years -- note we're coding this result as 2020 so year will be numeric in output file */
  ivregress 2sls ln_enr_up (got_road=t) left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < `b' & inrange(year, 2010, 2015), robust cluster(vgroup)
  append_est_to_file using $f, b(got_road) s("`b',2020,iv")
}
restore

/* run matlab to create coefplot */
// shell matlab -r coefplot_v

/*******************************************************************/
/* 2. create coefplot data: first stage and reduced form over time */
/*******************************************************************/
use $tmp/dise_rd_table_data_new, clear
qui quireg ln_enr_up t left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 200, cluster(vgroup)
keep if e(sample)

global f $tmp/rf_ests.csv
cap erase $f
append_to_file using $f, s(b,se,p,n,year,spec)
capdrop treatment

gen treatment = 0
forval year = 2003/2015 {
  quireg ln_enr_up t ln_enr_up_2002 ln_enr_p_2002 left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 160 & year == `year', title(`year')
  append_est_to_file using $f, b(t) s("`year',rf")
}
forval year = 2003/2015 {
  qui replace treatment = (comp_year <= `year')
  quireg treatment t ln_enr_up_2002 ln_enr_p_2002 left right ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 160 & year == 2011, title(`year')
  append_est_to_file using $f, b(t) s("`year',fs")
}

preserve
import delimited using $f, clear 

gen b_up   = b + 1.96 * se
gen b_down = b - 1.96 * se

/* combined */
replace year = year + .15 if spec == "rf"
twoway ///
  (rcap b_up b_down year if spec == "fs", color(black) ) (scatter b year if spec == "fs", color(black)) ///
  (rcap b_up b_down year if spec == "rf", lpattern("-") color("128 0 0") ) (scatter b year if spec == "rf", color("128 0 0")), ///
  xlab(2005 2010 2015) legend(order(1 3) lab(1 "First Stage") lab(3 "Reduced Form")) yline(0, lcolor(gs8)) xtitle("Year") ytitle("Point Estimate")
graphout dise_rd_combined, pdf
restore

/*************************/
/* 3. RD table for paper */
/*************************/

use $tmp/dise_rd_table_data_new, clear
keep if inrange(year, 2011, 2015)

global f $tmp/rd_ests.csv
cap erase $f

/* first stage */
areg got_road t left right ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch if abs(pop_rd) < 160 & inrange(year, 2011, 2015), absorb(dist_high_fe) cluster(vgroup)
store_est_tpl using $f, coef(t) name(r1) all

/* reduced form -- upper primary enrollment */
areg ln_enr_up t left right ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch if abs(pop_rd) < 160 & inrange(year, 2011, 2015), absorb(dist_high_fe) cluster(vgroup)
store_est_tpl using $f, coef(t) name(r2) all

/* IV -- upper primary enrollment */
ivregress 2sls ln_enr_up (got_road=t) left right ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch i.dist_high_fe if abs(pop_rd) < 160 & inrange(year, 2011, 2015), vce(cluster vgroup)
store_est_tpl using $f, coef(got_road) name(r3) all

/*********************************/
/* 4. Placebo RD table for paper */
/*********************************/
use $tmp/rd_incl_placebo, clear
keep if inrange(year, 2011, 2015) & state_sample == 0

/* first stage */
areg got_road t left right ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch if abs(pop_rd) < 160 & inrange(year, 2011, 2015), absorb(dist_high_fe) cluster(vgroup)
store_est_tpl using $f, coef(t) name(rp1) all

/* reduced form -- upper primary enrollment */
areg ln_enr_up t left right ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch if abs(pop_rd) < 160 & inrange(year, 2011, 2015), absorb(dist_high_fe) cluster(vgroup)
store_est_tpl using $f, coef(t) name(rp2) all

/* send estimates to latex template */
table_from_tpl, t(~/code/dise/tpl/table_rd.tex) r($f) o($out/table_rd_new.tex)

/*********************/
/* 6. RD binscatters */
/*********************/
use $tmp/dise_rd_table_data_new, clear
keep if inrange(year, 2011, 2015)

/* binscatter -- first stage */
rd got_road pop_rd if inrange(year, 2011, 2015), bins(40) degree(1) absorb(dist_high_fe) cluster(vgroup) control(ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch) bw xtitle("Village Population minus Treatment Threshold") ytitle("New Village Road")
graphout fig_fs_pooled_new, large pdf

/* binscatter - upper primary */
rd ln_enr_up pop_rd if inrange(year, 2011, 2015), bins(40) degree(1) absorb(dist_high_fe) cluster(vgroup) control(ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all pc01_lit_rate pc01_vd_m_sch pc01_vd_p_sch) bw xtitle("Village Population minus Treatment Threshold") ytitle("Log Upper Primary Enrollment, Mean 2011-2015")
graphout fig_rf_pooled_new, large pdf


