global out ~/iec/output/dise

global sumlist schcnt enr_over_pop ln_enr_total ln_enr_p ln_enr_up ln_pass ln_high_score pc01_lit_rate sc_share pc01_vd_dist_town bpl_asset0
global graphlist ln_enr_up ln_enr_total pc01_lit_rate sc_share enr_over_pop pc01_vd_dist_town schcnt bpl_asset0

use $tmp/dise_rd_table_data_new, clear
drop m607 pass7

/* get BPL baseline poverty level */
merge m:1 pc01_state_id pc01_village_id using $tmp/dise_bpl, keep(master match) nogen

/* get exam variables */
ren year dise_year
merge 1:1 pc01_state_id pc01_village_id dise_year using $tmp/dise_table_data, keepusing(pass7 m607) nogen keep(master match)
ren dise_year year

gen ln_pass = ln(pass7 + 1)
gen ln_high_score = ln(m607 + 1)
drop if mi(ln_enr_up_2002)

/* get some PCA and VD variables */
ext_get, src(pca01r) get(pc01_pca_p_lit pc01_pca_tot_p)
ext_get, src(vd01) get(pc01_vd_dist_town)

gen enr_over_pop = enr_total / pc01_pca_tot_p

/* label stuff */
cap label var pc11_pca_tot_p_sch "Village Population (2001)"
cap label var pc01_pca_tot_p_sch "Village Population (2001)"
cap label var pc01_vd_p_sch "Number of Primary Schools (2001)"
cap label var pc01_vd_m_sch "Number of Middle Schools (2001)"
cap label var pc01_vd_dist_town "Distance to Nearest Town (km, 2001)"
cap label var litrate_p01 "Literacy Rate (2001)"
cap label var sc_share "Scheduled Caste Population Share (2001)"
cap label var bpl_asset0 "Share of Asset-Poor Households"
label var ln_enr_up "Log Middle Enrollment (grades 6-8)"  
label var ln_enr_total "Total Enrollment (grades 1-8)"
label var pc01_lit_rate "Literacy Rate"
label var enr_over_pop "Enrollment Divided by Population"
save $tmp/foo, replace


/* for each variable of interest:
 - generate an estimate for the balance table
 - generate a scatterplot
*/

/*************************/
/* create balance table  */
/*************************/
cap erase $tmp/dise_rd_balance.csv
foreach v in $sumlist {

  /* set year to 2005 for exam variables */
  local year 2001
  if inlist("`v'", "ln_pass", "ln_high_score") local year 2005

  /* run RD spec for year == 2002 and store template */
  quireg `v' t left right if band & year == `year', absorb(subd_high_fe) title(`v')
  store_est_tpl using $tmp/dise_rd_balance.csv, coef(t) name(`v') format("%6.3f") beta se
}
table_from_tpl, t(~/iecmerge/paul/dise/tpl/rd_baseline.tpl) r($tmp/dise_rd_balance.csv) o($out/app_table_rd_baseline_new.tex)

/**********************/
/* create binscatters */
/**********************/
local c = 0
foreach v in $graphlist {

  /* set year to 2005 for exam variables [none in graph list] */
  local year 2001
  if inlist("`v'", "ln_pass", "ln_high_score") local year 2005
  
  /* get the variable label for this var */
  local title: var label `v'
    
  /* hack to only put X axis title on bottom two graphs only (i.e. #7 and #8) */
  local c = `c' + 1
  if `c' >= 7 {
    local xtitle `"xtitle("Population minus Eligibility Threshold (2001) ")"'
  }

  /* residualize output variable on subdistrict fixed effects */
  qui areg `v' ln_enr_up_2002 ln_enr_p_2002 ln_ec98_emp_all if year == `year', absorb(dist_high_fe)
  predict `v'_resid, resid

  rd `v'_resid pop_rd if year == `year', bw name(`v') msize(small) `xtitle' title("`title'", size(medsmall)) ylabel(#2,labsize(small)) bins(30) s(-140) e(140) degree(1)

  graphout bin_`v'
  drop `v'_resid
}
  
/* combine graphs for balance table */
graph combine $graphlist, xcommon graphregion(color(white)) rows(4)
graphout rd_balance_new, pdf large

/* create 2011 village population RD graph */
ext_get, src(pca11r) get(pc11_pca_tot_p)
local xtitle xtitle("Population minus Eligibility Threshold")
rd pc11_pca_tot_p pop_rd if year == 2011, bw name(pc11_pca_tot_p) msize(small) `xtitle' ylabel(#2,labsize(small)) bins(30) s(-150) e(150) degree(1)
graphout rd_pc11_pop, pdf large
