/* remove any previous versions of our output file, which will capture
our summary stats */
cap rm $tmp/dise_sumstats.csv
global out ~/iec/output/dise

use $dise/dise_village_new_short, clear

/* get literacy rate */
ext_get, src(pca01r) get(pc01_pca_p_lit pc01_pca_tot_p)
gen pc01_lit_rate = pc01_pca_p_lit / pc01_pca_tot_p

/* drop villages with outlier populations */
drop if !inrange(pop, 100, 5000)

/* keep 2002 only, since these are baseline stats */
keep if year == 2002

/* drop if missing road information, since summary table splits on this */
drop if mi(app_pr)

save $tmp/dise_summary_stats_new, replace

/********************************************************/
/* summary statistics, split by whether has road or not */
/********************************************************/
use $tmp/dise_summary_stats_new, clear

/* label summary vars of interest */
label var pc01_pca_tot_p "Population (2001 Census)"
label var pc01_lit_rate "Literacy rate (2001 Census)"
label var ec98_emp_all "Non-farm Employment (1998 Economic Census)"
label var schcnt "Number of Primary and Middle Schools"
label var enr_total "Total Enrollment (grades 1-8)"
label var enr_up "Total Middle Enrollment (grades 6-8)"
label var enr_p "Total Primary Enrollment (grades 1-5)"

/* summarize non-exam vars */
foreach var in pc01_pca_tot_p ec98_emp_all schcnt enr_total enr_p enr_up {
  sum `var'
  store_val_tpl using $tmp/dise_sumstats.csv, name("`var'_mean") value(`r(mean)') format("%5.1f")
  store_val_tpl using $tmp/dise_sumstats.csv, name("`var'_sd") value(`r(sd)') format("%5.1f")
}

/* summarize exam vars (in 2005) */
use $tmp/dise_exams, clear
keep if dise_year == 2005
label var pass7 "Middle School Exam Passers (2005)"
label var win7 "Exam Passers with Distinction (2005)"
foreach var in  pass7 win7 {
  sum `var'
  store_val_tpl using $tmp/dise_sumstats.csv, name("`var'_mean_05") value(`r(mean)') format("%5.1f")
  store_val_tpl using $tmp/dise_sumstats.csv, name("`var'_sd_05") value(`r(sd)') format("%5.1f")
}  

/* save data into tpl */
table_from_tpl, t(~/iecmerge/paul/dise/tpl/dise_sumstats_tpl.tex) r($tmp/dise_sumstats.csv) o($out/table_summary_new.tex)

